@@ -7,6 +7,7 @@ from courseaffils.models import Course
 class CourseAdminForm(forms.ModelForm):
     class Meta:
         model = Course
+        exclude = []
 
     if hasattr(settings, 'COURSEAFFILS_COURSESTRING_MAPPER'):
         course_string = settings.COURSEAFFILS_COURSESTRING_MAPPER.widget()
@@ -118,6 +119,8 @@ class CourseAdminForm(forms.ModelForm):
                     user = User(username=username)
                     if password:
                         user.set_password(password)
+                    else:
+                        user.set_unusable_password()
                     user.save()
                 user.groups.add(group)
                 if also_faculty and self.cleaned_data['faculty_group']:
