@@ -1,6 +1,3 @@
-import django.dispatch
-#user_logged_in = django.dispatch.Signal(providing_args=[])
-
 from django.contrib.auth.models import Group
 from django.conf import settings
 
